##############################################################
:mod:`.global_options <highcharts_core.global_options>`
##############################################################

**Module Contents**

.. toctree::
  :titlesonly:

  language/index
  shared_options

--------------

.. module:: highcharts_core.global_options

***************************
Sub-components
***************************

.. list-table::
  :widths: 60 40
  :header-rows: 1

  * - Module
    - Classes / Functions
  * - :mod:`.global_options <highcharts_core.global_options>`
    -
  * - :mod:`.global_options.language <highcharts_core.global_options.language>`
    - :class:`Language <highcharts_core.global_options.language.Language>`
  * - :mod:`.global_options.language.accessibility <highcharts_core.global_options.language.accessibility>`
    - :class:`AccessibilityLanguageOptions <highcharts_core.global_options.language.accessibility.AccessibilityLanguageOptions>`
  * - :mod:`.global_options.language.accessibility.announce_new_data <highcharts_core.global_options.language.accessibility.announce_new_data>`
    - :class:`AnnounceNewDataLanguageOptions <highcharts_core.global_options.language.accessibility.announce_new_data.AnnounceNewDataLanguageOptions>`
  * - :mod:`.global_options.language.accessibility.axis <highcharts_core.global_options.language.accessibility.axis>`
    - :class:`AxisLanguageOptions <highcharts_core.global_options.language.accessibility.axis.AxisLanguageOptions>`
  * - :mod:`global_options.language.accessibility.chart_types <highcharts_core.global_options.language.accessibility.chart_types>`
    - :class:`ChartTypesLanguageOptions <highcharts_core.global_options.language.accessibility.chart_types.ChartTypesLanguageOptions>`
  * - :mod:`global_options.language.accessibility.exporting <highcharts_core.global_options.language.accessibility.exporting>`
    - :class:`ExportingLanguageOptions <highcharts_core.global_options.language.accessibility.exporting.ExportingLanguageOptions>`
  * - :mod:`global_options.language.accessibility.legend <highcharts_core.global_options.language.accessibility.legend>`
    - :class:`LegendLanguageOptions <highcharts_core.global_options.language.accessibility.legend.LegendLanguageOptions>`
  * - :mod:`global_options.language.accessibility.range_selector <highcharts_core.global_options.language.accessibility.range_selector>`
    - :class:`RangeSelectorLanguageOptions <highcharts_core.global_options.language.accessibility.range_selector.RangeSelectorLanguageOptions>`
  * - :mod:`global_options.language.accessibility.screen_reader_section <highcharts_core.global_options.language.accessibility.screen_reader_section>`
    - :class:`ScreenReaderSectionLanguageOptions <highcharts_core.global_options.language.accessibility.screen_reader_section.ScreenReaderSectionLanguageOptions>`
      :class:`ScreenReaderSectionAnnotationLanguage <highcharts_core.global_options.language.accessibility.screen_reader_section.ScreenReaderSectionAnnotationLanguage>`
  * - :mod:`global_options.language.accessibility.series <highcharts_core.global_options.language.accessibility.series>`
    - :class:`SeriesLanguageOptions <highcharts_core.global_options.language.accessibility.series.SeriesLanguageOptions>`
      :class:`SeriesSummaryLanguageOptions <highcharts_core.global_options.language.accessibility.series.SeriesSummaryLanguageOptions>`
      :class:`SeriesTypeDescriptions <highcharts_core.global_options.language.accessibility.series.SeriesTypeDescriptions>`
  * - :mod:`global_options.language.accessibility.sonification <highcharts_core.global_options.language.accessibility.sonification>`
    - :class:`SonificationLanguageOptions <highcharts_core.global_options.language.accessibility.sonification.SonificationLanguageOptions>`
  * - :mod:`global_options.language.accessibility.table <highcharts_core.global_options.language.accessibility.table>`
    - :class:`TableLanguageOptions <highcharts_core.global_options.language.accessibility.table.TableLanguageOptions>`
  * - :mod:`global_options.language.accessibility.zoom <highcharts_core.global_options.language.accessibility.zoom>`
    - :class:`ZoomLanguageOptions <highcharts_core.global_options.language.accessibility.zoom.ZoomLanguageOptions>`
  * - :mod:`.global_options.language.export_data <highcharts_core.global_options.language.export_data>`
    - :class:`ExportDataLanguageOptions <highcharts_core.global_options.language.export_data.ExportDataLanguageOptions>`
  * - :mod:`.global_options.language.navigation <highcharts_core.global_options.language.navigation>`
    - :class:`NavigationLanguageOptions <highcharts_core.global_options.language.navigation.NavigationLanguageOptions>`
      :class:`PopupLanguageOptions <highcharts_core.global_options.language.navigation.PopupLanguageOptions>`
  * - :mod:`.global_options.shared_options <highcharts_core.global_options.shared_options>`
    - :class:`SharedOptions <highcharts_core.global_options.shared_options.SharedOptions>`
